@@ -51,7 +51,7 @@ struct _SessionObject {
 static gboolean checkduplication (gchar *sessionname, GSList **sess_list);
 static gboolean is_blank (gchar *str);
 static gboolean edit_session_name (gchar *title, gchar **editsession, 
-			GSList **sess_list, GtkWidget **dialog);
+			GSList **sess_list, GtkWidget **dialog, GtkWidget *parent);
 static gint session_compare (gconstpointer a, gconstpointer b);
 static gint sessionfile_compare (gconstpointer a, gconstpointer b);
 static void delete_sessions (GSList *sess_list); 
@@ -91,23 +91,30 @@ is_blank (gchar *str)
 
 static gboolean
 edit_session_name (gchar *title, gchar **editsession, 
-			GSList **sess_list, GtkWidget **dialog)
+			GSList **sess_list, GtkWidget **dialog, GtkWidget *parent_dlg)
 {
   GtkWidget *vbox;
   GtkWidget *entry;
   GtkWidget *frame;
-  *dialog = gnome_dialog_new (title, GNOME_STOCK_BUTTON_CANCEL,
-				GNOME_STOCK_BUTTON_OK,
-				NULL);
-  gnome_dialog_close_hides (GNOME_DIALOG (*dialog), TRUE);
-  gtk_window_set_policy (GTK_WINDOW (*dialog), FALSE, TRUE, FALSE);
+  char      *old_session_name = NULL;
+
+  if (*editsession)
+    old_session_name = g_strdup (*editsession);
+
+  *dialog = gtk_dialog_new_with_buttons (title,
+					 GTK_WINDOW (parent_dlg),
+					 GTK_DIALOG_MODAL,
+					 GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+					 GTK_STOCK_OK, GTK_RESPONSE_OK,
+					 NULL);
   gtk_window_set_default_size (GTK_WINDOW (*dialog), 400, -1);
 
+  gtk_window_set_transient_for (GTK_WINDOW (*dialog), GTK_WINDOW (parent_dlg));
   vbox = gtk_vbox_new (FALSE, GNOME_PAD_SMALL);
   gtk_container_set_border_width (GTK_CONTAINER (vbox), GNOME_PAD_SMALL);
 
-  gtk_box_pack_start (GTK_BOX (GNOME_DIALOG (*dialog)->vbox), vbox,
-			TRUE, TRUE, 0);
+  gtk_box_pack_start (GTK_BOX (GTK_DIALOG (*dialog)->vbox), vbox,
+		      TRUE, TRUE, 0);
   frame = gtk_frame_new (title);
   gtk_container_add (GTK_CONTAINER(vbox),frame);
   entry = gtk_entry_new();
@@ -119,37 +126,47 @@ edit_session_name (gchar *title, gchar **editsession,
 
   gtk_widget_show_all (*dialog); 
 
-  while (gnome_dialog_run (GNOME_DIALOG (*dialog)) == 1) {  
+  while (gtk_dialog_run (GTK_DIALOG (*dialog)) == GTK_RESPONSE_OK) {  
+    gboolean name_changed = TRUE;
+
     *editsession = gtk_editable_get_chars (GTK_EDITABLE (entry),0,-1);
+    if (old_session_name && !strcmp (old_session_name, *editsession))
+      name_changed = FALSE;
+
     if (is_blank (*editsession)) {
       GtkWidget *msgbox;
       gtk_widget_show (*dialog);
-      msgbox = gnome_message_box_new (_("The session name cannot be empty"),
- 			GNOME_MESSAGE_BOX_ERROR,
-			GNOME_STOCK_BUTTON_OK,
-			NULL);
-      gnome_dialog_set_parent (GNOME_DIALOG (msgbox), GTK_WINDOW (*dialog));
-      gnome_dialog_run (GNOME_DIALOG (msgbox));
+      msgbox = gtk_message_dialog_new (GTK_WINDOW (parent_dlg),
+				       GTK_DIALOG_MODAL,
+				       GTK_MESSAGE_ERROR,
+				       GTK_BUTTONS_OK,
+				       _("The session name cannot be empty"));
+      gtk_dialog_run (GTK_DIALOG (msgbox));
+      gtk_widget_destroy (msgbox);
     } 
-    else if(checkduplication(*editsession, sess_list)) {
+    else if (name_changed && checkduplication (*editsession, sess_list)) {
       GtkWidget *msgbox;
       gtk_widget_show (*dialog);
-      msgbox = gnome_message_box_new (_("The session name already exists"),
- 			GNOME_MESSAGE_BOX_ERROR,
-			GNOME_STOCK_BUTTON_OK,
-			NULL);
-      gnome_dialog_set_parent (GNOME_DIALOG (msgbox), GTK_WINDOW (*dialog));
-      gnome_dialog_run (GNOME_DIALOG (msgbox));
+      msgbox = gtk_message_dialog_new (GTK_WINDOW (parent_dlg),
+				       GTK_DIALOG_MODAL,
+				       GTK_MESSAGE_ERROR,
+				       GTK_BUTTONS_OK,
+				       _("The session name already exists"));
+      gtk_dialog_run (GTK_DIALOG (msgbox));
+      gtk_widget_destroy (msgbox);
     }
     else {
       gtk_widget_destroy (*dialog);
       *dialog = NULL;
+      g_free (old_session_name);
       return TRUE;
     }
   }
   
   gtk_widget_destroy (*dialog);
   *dialog = NULL;
+  g_free (old_session_name);
+
   return FALSE;
 }
 
@@ -163,11 +180,11 @@ checkduplication (gchar *sessionname, GSList **sess_list)
   return FALSE;
 }
 void 
-session_list_add_dialog (GSList **sess_list, GtkWidget **dialog)
+session_list_add_dialog (GSList **sess_list, GtkWidget **dialog, GtkWidget *parent_dlg)
 {
   gchar *new_session_name = NULL;
     
-  if(edit_session_name (_("Add a new session"), &new_session_name, sess_list, dialog)) {
+  if(edit_session_name (_("Add a new session"), &new_session_name, sess_list, dialog, parent_dlg)) {
     *sess_list = g_slist_prepend (*sess_list,g_strdup(new_session_name));
     *sess_list = g_slist_sort (*sess_list, (GCompareFunc)session_compare);
     spc_write_state ();
@@ -192,13 +209,13 @@ session_list_delete (GSList **sess_list, const gchar *old_session_name,
 
 void
 session_list_edit_dialog (GSList **sess_list, const gchar *old_session_name,
-			  GHashTable **hash, GtkWidget **dialog)
+			  GHashTable **hash, GtkWidget **dialog, GtkWidget *parent_dlg)
 {
   GSList *temp = NULL;
   gchar *edited_session_name = NULL;
   edited_session_name = g_strdup(old_session_name);
   if(edit_session_name (_("Edit session name"), &edited_session_name, 
-                          sess_list, dialog)) {
+                          sess_list, dialog, parent_dlg)) {
     for(temp = *sess_list; temp; temp=temp->next) {
       if(!strcmp((gchar *)temp->data, old_session_name)) {
         temp->data = g_strdup(edited_session_name);
